@@ -9,7 +9,7 @@ use std::{
 /// # Safety
 ///
 /// Up to the user to make sure the usage of the shared object is safe
-#[derive(Debug, Clone, Default)]
+#[derive(Debug, Default)]
 pub struct Shared<T>(Rc<UnsafeCell<T>>);
 
 impl<T> Shared<T> {
@@ -33,6 +33,12 @@ impl<T> Shared<T> {
     }
 }
 
+impl<T> Clone for Shared<T> {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+
 impl<T> Deref for Shared<T> {
     type Target = T;
 
